summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/myconfig.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/myconfig.py b/lib/myconfig.py
index 41f0b9d..fb77c0c 100644
--- a/lib/myconfig.py
+++ b/lib/myconfig.py
@@ -142,10 +142,10 @@ class MyConfig:
return 9 # minimum word occurrence in n-gram table
def getPartialWordThreshold(self):
- return 0.60 # the first 60% in position
+ return 0.50 # the first 50% in position
def getNewWordThreshold(self):
- return 0.79 # the first 79% in position, subject verb object.
+ return 0.60 # the first 60% in position, subject verb object.
def getMinimumEntropy(self):
return 0.01